import type { CanvasContext, DisplayObject } from '@antv/g-lite';
import type { FontLoader } from '../FontLoader';
import type { RendererContribution, RendererContributionContext } from '../interfaces';
/**
 * One of the biggest features that CanvasKit offers over the HTML Canvas API is paragraph shaping.
 * To use text your applicatoin, supply a font file and use Promise.all to run your code when both CanvasKit and the font file are ready.
 *
 * @see https://skia.org/docs/user/modules/quickstart/#text-shaping
 * @see https://fiddle.skia.org/c/@Canvas_drawText
 *
 * Depend on volatile Google Fonts:
 * @see https://github.com/flutter/flutter/issues/85793
 *
 * CJK Fonts:
 * @see https://github.com/flutter/flutter/issues/77212
 * @see https://github.com/flutter/flutter/issues/53897
 *
 * Emoji:
 * @see https://github.com/flutter/flutter/issues/76248
 */
export declare class TextRenderer implements RendererContribution {
    private context;
    private fontLoader;
    constructor(context: CanvasContext, fontLoader: FontLoader);
    render(object: DisplayObject, context: RendererContributionContext): void;
}
//# sourceMappingURL=Text.d.ts.map